[data-v-0e55c24b]:root{--main-font-family: DM Sans, sans-serif}[data-v-0e55c24b]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-0e55c24b]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-0e55c24b]{background-color:#fff;padding:10px}.script-card[data-v-0e55c24b]{width:300px;height:150px;cursor:pointer}.script-card[data-v-0e55c24b]:hover{box-shadow:0 0 15px #0000001a}[data-v-14680ef5]:root{--main-font-family: DM Sans, sans-serif}[data-v-14680ef5]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-14680ef5]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-14680ef5]{background-color:#fff;padding:10px}.new-script-card[data-v-14680ef5]{width:300px;height:150px;display:flex;justify-content:center;align-items:center;cursor:pointer}.new-script-card[data-v-14680ef5]:hover{box-shadow:0 0 15px #0000001a}.new-script-card .card-content[data-v-14680ef5]{display:flex;align-items:center;gap:10px;flex-direction:column}.choose-type[data-v-b0d14829]{width:100%;height:100%;display:flex;justify-content:center;align-items:center;padding:40px 0}.option[data-v-b0d14829]{width:120px;height:50px;border-radius:8px;display:flex;justify-content:center;align-items:center;border-width:1px;.option-content[data-v-b0d14829] {display: flex; align-items: center; gap: 8px;}}.option[data-v-b0d14829]:before{display:none}.scripts-container[data-v-00f8f457]{padding-top:40px}.v-enter-active[data-v-00f8f457],.v-leave-active[data-v-00f8f457]{transition:all var(--e9cb4458) ease}.v-enter-from[data-v-00f8f457],.v-leave-to[data-v-00f8f457]{transform:scale(0)}
