import{d as h,eA as w,eB as k,r as x,G as y,b as n,c as l,w as t,ev as b,eC as I,u as d,bf as C,ez as f,f as s,I as B,aq as N,eD as D,bq as S,bh as V,v as A,eE as E,eF as L,e as g,a as p,ex as T}from"./outputWidgets.fdae7e91.js";import{h as $,s as q}from"./icons.59384d21.js";import{_ as z}from"./logo.084e5d7c.js";import{B as F}from"./BaseLayout.f70dd29d.js";import{N as H}from"./NavbarControls.ba9053bb.js";import{c as M}from"./index.5b4488d8.js";import"./workspaces.f5bd76ac.js";import"./record.f963a373.js";import"./pubsub.61789656.js";import"./url.f60fbe92.js";import"./popupNotifcation.bcd8b25c.js";import"./asyncComputed.43537aae.js";import"./index.032f08d9.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.ed9adb70.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.a382dcd1.js";import"./ant-design.f2f7cc3b.js";import"./index.dedb9dc3.js";import"./Title.e4079793.js";import"./Text.2d7466b9.js";import"./index.1bf0713d.js";import"./Link.3418723f.js";import"./index.42add8ec.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="dec2cd90-2a87-415f-90a6-8575716b1b90",e._sentryDebugIdIdentifier="sentry-dbid-dec2cd90-2a87-415f-90a6-8575716b1b90")}catch{}})();const R=h({__name:"Sidebar",setup(e){var m;const o=w(),c=k(),r=x((m=c.name)!=null?m:"forms"),u=y(()=>[{name:"Home",icon:$,path:"home"},{name:"Settings",icon:q,path:"settings"}]),i=_=>{o.push(_.path),r.value=_.path};return(_,Q)=>(n(),l(d(V),{"inline-collapsed":""},{default:t(()=>[(n(!0),b(S,null,I(u.value,a=>(n(),l(d(C),{key:a.name,role:"button",class:f({active:r.value===a.path}),tabindex:"0",onClick:U=>i(a)},{icon:t(()=>[s(B,{class:f({active:r.value===a.path}),path:a.icon,width:"20",height:"20"},null,8,["class","path"])]),title:t(()=>[N(D(a.name),1)]),_:2},1032,["class","onClick"]))),128))]),_:1}))}});const W={},v=e=>(E("data-v-81cd596e"),e=e(),L(),e),G={class:"logo"},P=v(()=>g("img",{src:z,alt:"Abstra cloud logo"},null,-1)),j=v(()=>g("span",null," Abstra ",-1)),J=[P,j];function K(e,o){return n(),b("div",G,J)}const O=A(W,[["render",K],["__scopeId","data-v-81cd596e"]]),ve=h({__name:"Workspace",setup(e){return(o,c)=>{const r=p("ant-button"),u=p("router-link"),i=p("router-view");return n(),l(F,null,{navbar:t(()=>[s(d(M),{style:{padding:"5px 25px"}},{title:t(()=>[s(O)]),extra:t(()=>[s(H,{"show-github-stars":""},{default:t(()=>[T("",!0)]),_:1})]),_:1})]),sidebar:t(()=>[s(R,{class:"sidebar"})]),content:t(()=>[s(i)]),_:1})}}});export{ve as default};
//# sourceMappingURL=Workspace.e15fd6f7.js.map
