import{C as n,A as d}from"./index.3195ba67.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b8b90040-befd-4d90-9f4b-bab30e1f226d",e._sentryDebugIdIdentifier="sentry-dbid-b8b90040-befd-4d90-9f4b-bab30e1f226d")}catch{}})();n.Panel=d;n.install=function(e){return e.component(n.name,n),e.component(d.name,d),e};
//# sourceMappingURL=index.cb3ea56f.js.map
