import{a as e,A as t,B as s}from"./Text.2d7466b9.js";import{A as o}from"./Link.3418723f.js";import{a as r,A as i}from"./Title.e4079793.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[a]="64b2f36d-f60c-4f99-882c-0ca349d398b3",n._sentryDebugIdIdentifier="sentry-dbid-64b2f36d-f60c-4f99-882c-0ca349d398b3")}catch{}})();e.Text=t;e.Title=r;e.Paragraph=i;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,t),n.component(e.Title.displayName,r),n.component(e.Paragraph.displayName,i),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.1bf0713d.js.map
