import{d as k,eB as B,eA as I,G as w,a as h,b as a,c as d,w as o,eJ as j,f as n,u as t,ev as l,eC as x,aq as g,eD as z,bq as C,ex as A,bg as D,cC as S}from"./outputWidgets.fdae7e91.js";import{B as $}from"./BaseLayout.f70dd29d.js";import{a as M}from"./asyncComputed.43537aae.js";import{_ as N}from"./component.vue_vue_type_script_setup_true_lang.53b0dbf7.js";import"./authorManager.adc33c37.js";import{a as P}from"./build.d2fa7aee.js";import"./index.30fe2a77.js";import{P as R}from"./project.1bad15ea.js";import{O as V}from"./organization.241846c8.js";import{B as q,a as E,c as L}from"./index.5b4488d8.js";import{A as O}from"./Text.2d7466b9.js";import"./gateway.8c35b4b8.js";import"./WarningFilled.d99917ef.js";import"./log.9c0911a3.js";import"./ant-design.f2f7cc3b.js";import"./index.dedb9dc3.js";import"./Title.e4079793.js";import"./index.26ed9813.js";import"./Link.3418723f.js";import"./index.6f560850.js";import"./TabPane.bbe4d3aa.js";import"./hasIn.e6601643.js";import"./index.55605cd2.js";import"./isNumeric.75337b1e.js";import"./icons.59384d21.js";import"./index.c40322e7.js";import"./FormItem.45b6065e.js";import"./index.cf4c23b9.js";import"./record.f963a373.js";import"./pubsub.61789656.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[s]="6e39c4ec-8030-4bd8-8248-0233792d8034",i._sentryDebugIdIdentifier="sentry-dbid-6e39c4ec-8030-4bd8-8248-0233792d8034")}catch{}})();const T={key:0},F={key:2},kt=k({__name:"Build",setup(i){const s=B(),c=I(),m=s.params.buildId,{result:e,loading:b}=M(async()=>{const r=await P.get(m),p=await R.get(r.projectId),u=await V.get(p.organizationId);return j({bs:r,project:p,organization:u})}),f=w(()=>!b.value&&e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.organization.name,path:`/organizations/${e.value.organization.id}`},{label:`Build ${m.split("-")[0]}`,path:`/projects/${e.value.project.id}/builds`}]:void 0);function y(){var r;(r=e.value)!=null&&r.project.id&&c.push({name:"builds",params:{projectId:e.value.project.id}})}return(r,p)=>{const u=h("router-link");return a(),d($,null,{navbar:o(()=>[n(t(L),{title:"Inspect Build",style:{padding:"5px 25px"},onBack:y},{breadcrumb:o(()=>[f.value?(a(),d(t(q),{key:0},{default:o(()=>[(a(!0),l(C,null,x(f.value,(_,v)=>(a(),d(t(E),{key:v},{default:o(()=>[n(u,{to:_.path},{default:o(()=>[g(z(_.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):A("",!0)]),_:1})]),content:o(()=>[t(b)?(a(),l("div",T,[n(t(D))])):t(e)?(a(),d(N,{key:1,"build-spec":t(e).bs},null,8,["build-spec"])):(a(),l("div",F,[n(t(S),{direction:"vertical"},{default:o(()=>[n(t(O),null,{default:o(()=>[g("Could not find build")]),_:1})]),_:1})]))]),_:1})}}});export{kt as default};
//# sourceMappingURL=Build.7ec80312.js.map
