import{C as t,E as i,K as d,a as b,M as f,c,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.68b4fde7.js";import"./outputWidgets.fdae7e91.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="b8a6400d-2852-4912-8c19-eb8a39fb3e38",e._sentryDebugIdIdentifier="sentry-dbid-b8a6400d-2852-4912-8c19-eb8a39fb3e38")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,b as KeyMod,f as MarkerSeverity,c as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.5723c212.js.map
