import{v as t,b as s,ev as d}from"./outputWidgets.fdae7e91.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="da224ddd-024f-49e3-848e-c79c25e9aa56",e._sentryDebugIdIdentifier="sentry-dbid-da224ddd-024f-49e3-848e-c79c25e9aa56")}catch{}})();const a={},o={class:"organization-settings"};function r(e,n){return s(),d("div",o,"Organization settings")}const f=t(a,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.b3b1caac.js.map
