import{T as n,A as t}from"./TabPane.bbe4d3aa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="8885f997-6b08-4eb0-9c06-8025d0e27d69",e._sentryDebugIdIdentifier="sentry-dbid-8885f997-6b08-4eb0-9c06-8025d0e27d69")}catch{}})();n.TabPane=t;n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.ff1a13ef.js.map
