import{v as r,a as o,b as i,c,i as d,T as p,j as u,P as _,C as b,M as l,s as f,k as s,l as g,m,n as y,p as v}from"./outputWidgets.fdae7e91.js";import{u as w,s as h,a}from"./index.032f08d9.js";import"./pubsub.61789656.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5e381b4a-d0bb-4c07-b7ad-7248aa844ee5",e._sentryDebugIdIdentifier="sentry-dbid-5e381b4a-d0bb-4c07-b7ad-7248aa844ee5")}catch{}})();const I={};function k(e,t){const n=o("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",k]]);class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await Promise.all([w(),h()]);const e=d({render:()=>g(x)});p.init(),u(e,a),P.init(),e.use(a),e.use(_),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",l),e.component("Message",f),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.458dd5ad.js.map
