import{_ as m}from"./Sidebar.vue_vue_type_script_setup_true_lang.0a4949b9.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.0d749b6e.js";import{D as l,E as u,F as b}from"./icons.59384d21.js";import{d,eB as f,G as _,a as g,b as y,c as v,w as t,f as r}from"./outputWidgets.fdae7e91.js";import{a as w}from"./asyncComputed.43537aae.js";import"./authorManager.adc33c37.js";import"./index.30fe2a77.js";import{O as z}from"./organization.241846c8.js";import{B as h}from"./BaseLayout.f70dd29d.js";import"./index.9026b0b4.js";import"./logo.084e5d7c.js";import"./Text.2d7466b9.js";import"./index.5b4488d8.js";import"./index.cf4c23b9.js";import"./record.f963a373.js";import"./pubsub.61789656.js";import"./gateway.8c35b4b8.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="20900c69-5bc8-4bec-b4a1-208b18aa50c5",a._sentryDebugIdIdentifier="sentry-dbid-20900c69-5bc8-4bec-b4a1-208b18aa50c5")}catch{}})();const A=d({__name:"Organization",setup(a){const n=f().params.organizationId,{result:o}=w(()=>z.get(n)),i=_(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:u,path:"members"},{name:"Billing",icon:b,path:"billing",unavailable:!0}]}];return(I,B)=>{const c=g("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(m,{class:"sidebar",sections:s})]),content:t(()=>[r(c)]),_:1})}}});export{A as default};
//# sourceMappingURL=Organization.9f850b52.js.map
