import{cw as f}from"./outputWidgets.fdae7e91.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="daff9a57-2060-4df6-8209-d11d6ec7efcf",e._sentryDebugIdIdentifier="sentry-dbid-daff9a57-2060-4df6-8209-d11d6ec7efcf")}catch{}})();const o=(e,d)=>{f.error({message:e,description:d})};export{o as p};
//# sourceMappingURL=popupNotifcation.bcd8b25c.js.map
