import{d as y,eB as h,b as s,ev as d,f as e,w as o,u as t,c as g,bq as w,aq as a,bg as v,cC as k}from"./outputWidgets.fdae7e91.js";import{a as I}from"./asyncComputed.43537aae.js";import"./authorManager.adc33c37.js";import{B as j,a as A}from"./build.d2fa7aee.js";import"./index.30fe2a77.js";import{P as B}from"./project.1bad15ea.js";import{_ as S}from"./component.vue_vue_type_script_setup_true_lang.53b0dbf7.js";import{a as T,A as x}from"./Title.e4079793.js";import{A as i}from"./Text.2d7466b9.js";import{A as C}from"./Link.3418723f.js";import"./gateway.8c35b4b8.js";import"./index.cf4c23b9.js";import"./record.f963a373.js";import"./pubsub.61789656.js";import"./WarningFilled.d99917ef.js";import"./log.9c0911a3.js";import"./ant-design.f2f7cc3b.js";import"./index.dedb9dc3.js";import"./index.26ed9813.js";import"./index.6f560850.js";import"./BaseLayout.f70dd29d.js";import"./index.5b4488d8.js";import"./TabPane.bbe4d3aa.js";import"./hasIn.e6601643.js";import"./index.55605cd2.js";import"./isNumeric.75337b1e.js";import"./icons.59384d21.js";import"./index.c40322e7.js";import"./FormItem.45b6065e.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[n]="735067c8-7a3e-47ef-9793-e5d13f3646ed",r._sentryDebugIdIdentifier="sentry-dbid-735067c8-7a3e-47ef-9793-e5d13f3646ed")}catch{}})();const D={key:0},L={key:2},pt=y({__name:"Live",setup(r){const p=h().params.projectId,{loading:c,result:l}=I(async()=>{const u=(await j.list(p)).find(b=>b.latest);if(!u)return null;const[f,_]=await Promise.all([A.get(u.id),B.get(p)]);return{buildSpec:f,project:_}});return(m,u)=>(s(),d(w,null,[e(t(T),null,{default:o(()=>[a("Live build")]),_:1}),e(t(x),null,{default:o(()=>[a(" This is where you can view your current active build. On this page, you can see the parts that make up your project and access the links to each form within it. ")]),_:1}),t(c)?(s(),d("div",D,[e(t(v))])):t(l)?(s(),g(S,{key:1,subdomain:t(l).project.subdomain,"is-live":!0,"build-spec":t(l).buildSpec},null,8,["subdomain","build-spec"])):(s(),d("div",L,[e(t(k),{direction:"vertical"},{default:o(()=>[e(t(i),null,{default:o(()=>[a("Install abstra using pip:")]),_:1}),e(t(i),{code:"",copyable:""},{default:o(()=>[a("pip install abstra")]),_:1}),e(t(i),null,{default:o(()=>[a("Start a new project using our CLI")]),_:1}),e(t(i),{code:"",copyable:""},{default:o(()=>[a("abstra serve my-new-project")]),_:1}),e(t(i),null,{default:o(()=>[a(" If you have any questions, please reach out to our "),e(t(C),{href:"https://discord.gg/abstra",target:"_blank"},{default:o(()=>[a(" discord channel ")]),_:1})]),_:1})]),_:1})]))],64))}});export{pt as default};
//# sourceMappingURL=Live.ff653d38.js.map
