import{N as _}from"./NavbarControls.ba9053bb.js";import{d as b,eA as f,eB as y,G as g,a as v,b as c,ev as h,f as e,w as a,u as s,e as k,bq as w,aq as x,c as S,eU as q,v as A}from"./outputWidgets.fdae7e91.js";import{A as B}from"./Text.2d7466b9.js";import{T as C,A as n}from"./TabPane.bbe4d3aa.js";import{c as I}from"./index.5b4488d8.js";import"./workspaces.f5bd76ac.js";import"./record.f963a373.js";import"./pubsub.61789656.js";import"./url.f60fbe92.js";import"./popupNotifcation.bcd8b25c.js";import"./asyncComputed.43537aae.js";import"./index.032f08d9.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.ed9adb70.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.a382dcd1.js";import"./ant-design.f2f7cc3b.js";import"./index.dedb9dc3.js";import"./Title.e4079793.js";import"./index.1bf0713d.js";import"./Link.3418723f.js";import"./index.42add8ec.js";import"./hasIn.e6601643.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="f9eaa706-b26d-4020-aae5-5a9aefc481c8",r._sentryDebugIdIdentifier="sentry-dbid-f9eaa706-b26d-4020-aae5-5a9aefc481c8")}catch{}})();const T={class:"content"},D=b({__name:"Settings",setup(r){const t=f(),o=y();function u(){t.push({name:"home"})}const m=g(()=>{switch(o.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function d(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const p=v("router-view");return c(),h(w,null,[e(s(I),{style:{padding:"5px 25px"},onBack:u},{extra:a(()=>[e(_,{"show-v-s-code-button":"","show-save-button":""})]),avatar:a(()=>[e(s(B),null,{default:a(()=>[x("Settings")]),_:1})]),footer:a(()=>[e(s(C),{"active-key":m.value,onChange:d},{default:a(()=>[e(s(n),{key:"style",tab:"Style"}),e(s(n),{key:"sidebar",tab:"Sidebar"}),e(s(n),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",T,[e(p,null,{default:a(({Component:l})=>[(c(),S(q(l)))]),_:1})])],64)}}});const ee=A(D,[["__scopeId","data-v-e35bc70e"]]);export{ee as default};
//# sourceMappingURL=Settings.c125cc39.js.map
