import{C as l}from"./Card.106f5f4c.js";import{d as C,L as I,bQ as c,f as r,bn as d,G as _,aL as M,cl as m}from"./outputWidgets.fdae7e91.js";import{F as a}from"./Form.d4070d32.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="efd27b46-0e72-472b-8c41-0df25048bf75",e._sentryDebugIdIdentifier="sentry-dbid-efd27b46-0e72-472b-8c41-0df25048bf75")}catch{}})();const x=()=>({prefixCls:String,title:d(),description:d(),avatar:d()}),u=C({compatConfig:{MODE:3},name:"ACardMeta",props:x(),slots:Object,setup(e,o){let{slots:n}=o;const{prefixCls:t}=I("card",e);return()=>{const i={[`${t.value}-meta`]:!0},s=c(n,e,"avatar"),v=c(n,e,"title"),b=c(n,e,"description"),D=s?r("div",{class:`${t.value}-meta-avatar`},[s]):null,p=v?r("div",{class:`${t.value}-meta-title`},[v]):null,g=b?r("div",{class:`${t.value}-meta-description`},[b]):null,y=p||g?r("div",{class:`${t.value}-meta-detail`},[p,g]):null;return r("div",{class:i},[D,y])}}}),G=()=>({prefixCls:String,hoverable:{type:Boolean,default:!0}}),f=C({compatConfig:{MODE:3},name:"ACardGrid",__ANT_CARD_GRID:!0,props:G(),setup(e,o){let{slots:n}=o;const{prefixCls:t}=I("card",e),i=_(()=>({[`${t.value}-grid`]:!0,[`${t.value}-grid-hoverable`]:e.hoverable}));return()=>{var s;return r("div",{class:i.value},[(s=n.default)===null||s===void 0?void 0:s.call(n)])}}});l.Meta=u;l.Grid=f;l.install=function(e){return e.component(l.name,l),e.component(u.name,u),e.component(f.name,f),e};a.useInjectFormItemContext=M;a.ItemRest=m;a.install=function(e){return e.component(a.name,a),e.component(a.Item.name,a.Item),e.component(m.name,m),e};export{f as G,u as M};
//# sourceMappingURL=index.cde590a7.js.map
