import{d,eB as g,G as l,a as b,b as f,c as v,w as r,f as s}from"./outputWidgets.fdae7e91.js";import{B as _}from"./BaseLayout.f70dd29d.js";import{a as h}from"./asyncComputed.43537aae.js";import"./authorManager.adc33c37.js";import"./index.30fe2a77.js";import{P as z}from"./project.1bad15ea.js";import{O as y}from"./organization.241846c8.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.0d749b6e.js";import{_ as I}from"./Sidebar.vue_vue_type_script_setup_true_lang.0a4949b9.js";import{z as w,H as B,I as $,J as k,K as P,L as C,n as D,M as L,s as M,D as x,E as O,F as E}from"./icons.59384d21.js";import"./index.cf4c23b9.js";import"./record.f963a373.js";import"./pubsub.61789656.js";import"./gateway.8c35b4b8.js";import"./logo.084e5d7c.js";import"./Text.2d7466b9.js";import"./index.5b4488d8.js";import"./index.9026b0b4.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="e1e79470-42c3-42f1-aace-6c313f590a97",o._sentryDebugIdIdentifier="sentry-dbid-e1e79470-42c3-42f1-aace-6c313f590a97")}catch{}})();const aa=d({__name:"Project",setup(o){const c=g().params.projectId,{result:a}=h(()=>z.get(c).then(async e=>{const t=await y.get(e.organizationId);return{project:e,organization:t}})),m=l(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=l(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:B},{name:"Connectors",path:"connectors",icon:$},{name:"Tables",path:"tables",icon:k},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:C},{name:"Files",path:"files",icon:D},{name:"Logs",icon:L,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:O,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:E,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=b("router-view");return f(),v(_,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{aa as default};
//# sourceMappingURL=Project.72b24983.js.map
