import"./outputWidgets.fdae7e91.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="b86cfdbb-2741-4ef8-b4c5-15739e699de2",x._sentryDebugIdIdentifier="sentry-dbid-b86cfdbb-2741-4ef8-b4c5-15739e699de2")}catch{}})();const d=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{d as u};
//# sourceMappingURL=uuid.980c423e.js.map
