import{eK as n}from"./outputWidgets.fdae7e91.js";import"./index.dedb9dc3.js";import{M as y}from"./Title.e4079793.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="df48eea2-cc77-46f5-bf6a-3f5236ef8170",e._sentryDebugIdIdentifier="sentry-dbid-df48eea2-cc77-46f5-bf6a-3f5236ef8170")}catch{}})();function o(e){return n.exports.isArray(e)?e.length===0?"[ ]":"[ ... ]":n.exports.isObject(e)?Object.keys(e).length===0?"{ }":"{ ... }":n.exports.isString(e)?`'${e}'`:n.exports.isUndefined(e)||n.exports.isNull(e)?"None":e===!0?"True":e===!1?"False":`${e}`}function u(e){if(n.exports.isArray(e))return"array";if(n.exports.isObject(e))return"object";throw new Error("treeKey called with non-object and non-array")}function c(e,r=[],t){const s=t?`'${t}': ${o(e)}`:o(e);if(n.exports.isArray(e)){const f=u(e);return[{title:s,key:[...r,f].join("/"),children:e.flatMap((i,l)=>c(i,[...r,f,`${l}`]))}]}else if(n.exports.isObject(e)){const f=u(e);return[{title:s,key:[...r,f].join("/"),children:Object.entries(e).flatMap(([i,l])=>c(l,[...r,f,i],i))}]}else return[{title:s,key:r.join("/"),children:[]}]}function k(e,r){return new Promise(t=>{y.confirm({title:e,onOk:()=>t(!0),okText:r==null?void 0:r.okText,onCancel:()=>t(!1),cancelText:r==null?void 0:r.cancelText})})}export{k as a,c as t};
//# sourceMappingURL=ant-design.f2f7cc3b.js.map
