import{d as z,$ as V,an as W,L as q,cR as Q,ab as B,N as w,f as i,U as s,bu as X,Q as d,aV as N,cS as Y,cT as G,x as H,a5 as u,a2 as f,bO as _,cU as J,bq as K,O as S,cV as Z}from"./outputWidgets.fdae7e91.js";import{B as I,b as j}from"./Text.2d7466b9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2dc9e650-9bce-4b58-a5eb-586b26a8cbd0",e._sentryDebugIdIdentifier="sentry-dbid-2dc9e650-9bce-4b58-a5eb-586b26a8cbd0")}catch{}})();var ee=globalThis&&globalThis.__rest||function(e,a){var o={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&a.indexOf(t)<0&&(o[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var n=0,t=Object.getOwnPropertySymbols(e);n<t.length;n++)a.indexOf(t[n])<0&&Object.prototype.propertyIsEnumerable.call(e,t[n])&&(o[t[n]]=e[t[n]]);return o};let P;const te=e=>{P={x:e.pageX,y:e.pageY},setTimeout(()=>P=null,100)};G()&&H(document.documentElement,"click",te,!0);const ne=()=>({prefixCls:String,visible:{type:Boolean,default:void 0},open:{type:Boolean,default:void 0},confirmLoading:{type:Boolean,default:void 0},title:u.any,closable:{type:Boolean,default:void 0},closeIcon:u.any,onOk:Function,onCancel:Function,"onUpdate:visible":Function,"onUpdate:open":Function,onChange:Function,afterClose:Function,centered:{type:Boolean,default:void 0},width:[String,Number],footer:u.any,okText:u.any,okType:String,cancelText:u.any,icon:u.any,maskClosable:{type:Boolean,default:void 0},forceRender:{type:Boolean,default:void 0},okButtonProps:f(),cancelButtonProps:f(),destroyOnClose:{type:Boolean,default:void 0},wrapClassName:String,maskTransitionName:String,transitionName:String,getContainer:{type:[String,Function,Boolean,Object],default:void 0},zIndex:Number,bodyStyle:f(),maskStyle:f(),mask:{type:Boolean,default:void 0},keyboard:{type:Boolean,default:void 0},wrapProps:Object,focusTriggerAfterClose:{type:Boolean,default:void 0},modalRender:Function,mousePosition:f()}),ce=z({compatConfig:{MODE:3},name:"AModal",inheritAttrs:!1,props:V(ne(),{width:520,confirmLoading:!1,okType:"primary"}),setup(e,a){let{emit:o,slots:t,attrs:n}=a;const[y]=W("Modal"),{prefixCls:r,rootPrefixCls:m,direction:A,getPopupContainer:v}=q("modal",e),[E,h]=Q(r);B(e.visible===void 0);const O=l=>{o("update:visible",!1),o("update:open",!1),o("cancel",l),o("change",!1)},F=l=>{o("ok",l)},L=()=>{var l,c;const{okText:x=(l=t.okText)===null||l===void 0?void 0:l.call(t),okType:T,cancelText:p=(c=t.cancelText)===null||c===void 0?void 0:c.call(t),confirmLoading:C}=e;return i(K,null,[i(_,d({onClick:O},e.cancelButtonProps),{default:()=>[p||y.value.cancelText]}),i(_,d(d({},J(T)),{},{loading:C,onClick:F},e.okButtonProps),{default:()=>[x||y.value.okText]})])};return()=>{var l,c;const{prefixCls:x,visible:T,open:p,wrapClassName:C,centered:D,getContainer:$,closeIcon:M=(l=t.closeIcon)===null||l===void 0?void 0:l.call(t),focusTriggerAfterClose:R=!0}=e,k=ee(e,["prefixCls","visible","open","wrapClassName","centered","getContainer","closeIcon","focusTriggerAfterClose"]),U=w(C,{[`${r.value}-centered`]:!!D,[`${r.value}-wrap-rtl`]:A.value==="rtl"});return E(i(Y,d(d(d({},k),n),{},{rootClassName:h.value,class:w(h.value,n.class),getContainer:$||(v==null?void 0:v.value),prefixCls:r.value,wrapClassName:U,visible:p!=null?p:T,onClose:O,focusTriggerAfterClose:R,transitionName:N(m.value,"zoom",e.transitionName),maskTransitionName:N(m.value,"fade",e.maskTransitionName),mousePosition:(c=k.mousePosition)!==null&&c!==void 0?c:P}),s(s({},t),{footer:t.footer||L,closeIcon:()=>i("span",{class:`${r.value}-close-x`},[M||i(X,{class:`${r.value}-close-icon`},null)])})))}}}),oe=()=>S(j(),["component"]),g=(e,a)=>{let{slots:o,attrs:t}=a;const n=s(s(s({},e),{component:"div"}),t);return i(I,n,o)};g.displayName="ATypographyParagraph";g.inheritAttrs=!1;g.props=oe();const de=g;var ae=globalThis&&globalThis.__rest||function(e,a){var o={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&a.indexOf(t)<0&&(o[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var n=0,t=Object.getOwnPropertySymbols(e);n<t.length;n++)a.indexOf(t[n])<0&&Object.prototype.propertyIsEnumerable.call(e,t[n])&&(o[t[n]]=e[t[n]]);return o};const le=Z(1,2,3,4,5),re=()=>s(s({},S(j(),["component","strong"])),{level:Number}),b=(e,a)=>{let{slots:o,attrs:t}=a;const{level:n=1}=e,y=ae(e,["level"]);let r;le.includes(n)?r=`h${n}`:(B(),r="h1");const m=s(s(s({},y),{component:r}),t);return i(I,m,o)};b.displayName="ATypographyTitle";b.inheritAttrs=!1;b.props=re();const ue=b;export{de as A,ce as M,ue as a};
//# sourceMappingURL=Title.e4079793.js.map
